@@ -6,7 +6,6 @@ from typing import Type, List, cast
 import spacy
 from pydantic import BaseModel
 from pymultirole_plugins.util import comma_separated_to_list
-from pymultirole_plugins.v1.processor import ProcessorBase, ProcessorParameters
 from pymultirole_plugins.v1.schema import Document, Sentence
 from pymultirole_plugins.v1.segmenter import SegmenterParameters, SegmenterBase
 from spacy.cli.download import download_model, get_compatibility, get_version
@@ -16,14 +15,14 @@ from wasabi import msg
 from pysegmenters_pysdb.pysbd_sentencizer import PySBDSentencizer
 
 
-class PySDBSegmenterParameters(SegmenterParameters, ProcessorParameters, ABC):
+class PySDBSegmenterParameters(SegmenterParameters, ABC):
     pass
 
 
 SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ar,hi,ur,fa,ru"
 
 
-class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
+class PySDBSegmenter(SegmenterBase, ABC):
     """Rule-based segmenter relying on [PySBD](https://github.com/nipunsadvilkar/pySBD).
     #need-language
     #languages:""" + SUPPORTED_LANGUAGES
@@ -49,10 +48,6 @@ class PySDBSegmenter(SegmenterBase, ProcessorBase, ABC):
                         document.sentences.append(Sentence(start=sent.start_char, end=end_token.idx + len(end_token)))
         return documents
 
-    def process(self, documents: List[Document], parameters: ProcessorParameters) \
-            -> List[Document]:
-        return self.segment(documents, parameters)
-
     @classmethod
     def get_model(cls) -> Type[BaseModel]:
         return PySDBSegmenterParameters
@@ -74,7 +69,7 @@ MODEL_SHORTCUTS = {
     "pt": "pt_core_news_sm", "fr": "fr_core_news_sm", "it": "it_core_news_sm",
     "nl": "nl_core_news_sm", "el": "el_core_news_sm", "nb": "nb_core_news_sm",
     "lt": "lt_core_news_sm", "xx": "xx_ent_wiki_sm", "zh": "zh_core_web_sm",
-    "ru": "ru_core_news_sm"
+    "ru": "ru_core_news_sm", "ja": "ja_core_news_sm"
 }
 
 
